@@ -1,14 +1,15 @@
 package GraphViz;
 
+use 5.006;
 use strict;
 use warnings;
-use vars qw($AUTOLOAD $VERSION);
+our $AUTOLOAD;
 
 use Carp;
 use Config;
 use IPC::Run qw(run binary);
 
-our $VERSION = '2.16';
+our $VERSION = '2.21';
 
 =pod
 
@@ -391,7 +392,7 @@ The 'node', 'edge' and 'graph' attributes allow you to specify global
 node, edge and graph attributes (in addition to those controlled by
 the special attributes described above). The value should be a hash
 reference containing the corresponding key-value pairs. For example,
-to make all nodes box-shaped (unless explicity given another shape):
+to make all nodes box-shaped (unless explicitly given another shape):
 
   my $g = GraphViz->new(node => {shape => 'box'});
 
@@ -1379,7 +1380,11 @@ GraphViz is deprecated in favour of L<GraphViz2>.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
+
+=head1 Repository
+
+L<https://github.com/ronsavage/GraphViz>
 
 =head1 AUTHOR
 
@@ -1387,14 +1392,16 @@ Leon Brocard: E<lt>F<acme@astray.com>E<gt>.
 
 Current maintainer: Ron Savage I<E<lt>ron@savage.net.auE<gt>>.
 
+My homepage: L<http://savage.net.au/>.
+
 =head1 COPYRIGHT
 
 Copyright (C) 2000-4, Leon Brocard
 
 =head1 LICENSE
 
-This module is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+This module is free software; you can redistribute it or modify it under the Perl License,
+a copy of which is available at L<http://dev.perl.org/licenses/>.
 
 =cut
 
